[PATCH i-g-t] tests/intel/xe_module_load: Rename enable_display module param

Lucas De Marchi lucas.demarchi at intel.com
Fri Aug 9 17:27:28 UTC 2024


enable_display is being renamed in the kernel since it's ambiguous:
https://lore.kernel.org/all/20240808180154.2495634-1-lucas.demarchi@intel.com/

Prepare for that renaming it in igt.

Signed-off-by: Lucas De Marchi <lucas.demarchi at intel.com>
---

After doing this I'm wondering if it would break anything in CI if
either

a) igt started passing both for some time
b) the kernel to have one additional enable_display module param,
   documented as deprecated,  that we keep for a couple of releases


 tests/intel/xe_module_load.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tests/intel/xe_module_load.c b/tests/intel/xe_module_load.c
index 0856a57c8..30259fc26 100644
--- a/tests/intel/xe_module_load.c
+++ b/tests/intel/xe_module_load.c
@@ -112,7 +112,7 @@ static const char * const unwanted_drivers[] = {
  * Description: Reload the Xe driver
  *
  * SUBTEST: reload-no-display
  * Description: Reload the Xe driver passing ``enable_display=0`` parameter
  *
  * SUBTEST: many-reload
  * Description: Reload the Xe driver many times
@@ -145,7 +145,7 @@ igt_main
 
 	igt_subtest("reload-no-display") {
 		igt_xe_driver_unload();
-		load_and_check_xe("enable_display=0");
+		load_and_check_xe("probe_display=0");
 		igt_xe_driver_unload();
 	}
 
@@ -112,7 +112,7 @@ static const char * const unwanted_drivers[] = {
  *
  * SUBTEST: reload-no-display
- * Description: Reload the Xe driver passing ``enable_display=0`` parameter
+ * Description: Reload the Xe driver passing ``probe_display=0`` parameter
  *
  * SUBTEST: many-reload
-- 
2.43.0



More information about the igt-dev mailing list